@@ -867,7 +867,7 @@
 /*
  * Define if large (64 bit file offsets) files are supported.
  */
-/* #undef HAVE_LARGEFILE_SUPPORT */
+#define HAVE_LARGEFILE_SUPPORT 1
 
 /*
  * Use OpenGL
@@ -1208,7 +1208,7 @@
 #define HAVE_VSWSCANF 1
 
 /* Define if fseeko and ftello are available.  */
-/* #undef HAVE_FSEEKO */
+#define HAVE_FSEEKO 1
 
 /* Define this if you are using gtk and gdk contains support for X11R6 XIM */
 /* #undef HAVE_XIM */
@@ -1246,6 +1246,9 @@
 /* Define if setpriority() is available. */
 #define HAVE_SETPRIORITY 1
 
+/* Define if xkbcommon is available */
+/* #undef HAVE_XKBCOMMON */
+
 /* Define if xlocale.h header file exists. */
 /* #undef HAVE_XLOCALE_H */
 
